"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const models_1 = require("../services/models");
const association_1 = require("../services/association");
const models_2 = require("../services/models");
const object_1 = require("../utils/object");
/**
 * Why does v3/Sequlize and v4/Sequelize does not extend? Because of
 * the transpile target, which is for v3/Sequelize and BaseSequelize ES5
 * and for v4/Sequelize ES6. This is needed for extending the original
 * Sequelize (version 4), which is an ES6 class: ES5 constructor-pattern
 * "classes" cannot extend ES6 classes
 */
class BaseSequelize {
    constructor() {
        this.thoughMap = {};
        this._ = {};
    }
    static extend(target) {
        object_1.extend(target, this);
    }
    /**
     * Prepares sequelize config passed to original sequelize constructor
     */
    static prepareConfig(config) {
        if (config.validateOnly) {
            return this.getValidationOnlyConfig(config);
        }
        return config;
    }
    static getValidationOnlyConfig(config) {
        return Object.assign({}, config, { name: '_name_', username: '_username_', password: '_password_', dialect: 'sqlite', dialectModulePath: __dirname + '/../utils/db-dialect-dummy' });
    }
    addModels(arg) {
        const models = models_1.getModels(arg);
        this.defineModels(models);
        models.forEach(model => model.isInitialized = true);
        this.associateModels(models);
        models_2.resolveScopes(models);
        models.forEach(model => this._[model.name] = model);
    }
    init(config) {
        if (config.modelPaths)
            this.addModels(config.modelPaths);
    }
    /**
     * Processes model associations
     */
    associateModels(models) {
        models.forEach(model => {
            const associations = association_1.getAssociations(model.prototype);
            if (!associations)
                return;
            associations.forEach(association => association_1.processAssociation(this, model, association));
        });
    }
}
exports.BaseSequelize = BaseSequelize;
//# sourceMappingURL=BaseSequelize.js.map